# FILE: bug75.tcl
#
#	Patches for Tcl 7.5
#
# Last modified on: $Date: 1998/06/30 19:25:38 $
# Last modified by: $Author: dgp $
#
# This file contains Tcl code which when sourced in a Tcl 7.5 interpreter
# will patch bugs in Tcl 7.5 fixed in later versions of Tcl.  It is not
# meant to be complete.  Bugs are patched here only as we discover the need
# to do so in writing other OOMMF software.

Oc_Log Log "Patching Tcl 7.5 bugs..." status

if {[string match unix $tcl_platform(platform)]} {

    # The subcommands copy, delete, rename, and mkdir were added to
    # the Tcl command 'file' in Tcl version 7.6.  The following command
    # approximates them on Unix platforms.  It may not agree with
    # the Tcl 7.6+ command 'file' in all of its functionality (notably
    # the way it reports errors).  Further refinements should be made as
    # needed.
    rename file Tcl7.5_file
    proc file {option args} {
        switch -exact $option {
            c    -
            co   -
            cop  -
            copy {
                # Translate -force into -f
                if {[string match -force [lindex $args 0]]} {
                    set args [lreplace $args 0 0 -f]
                }
                uplevel exec cp $args
            }
            de     -
            del    -
            dele   -
            delet  -
            delete {
                if {[string match -force [lindex $args 0]]} {
                    set args [lreplace $args 0 0 -f]
                }
                catch {uplevel exec rm $args}
            }
            mk    -
            mkd   -
            mkdi  -
            mkdir {
                uplevel exec mkdir $args
            }
            ren    -
            rena   -
            renam  -
            rename {
                if {[string match -force [lindex $args 0]]} {
                    set args [lreplace $args 0 0 -f]
                }
                uplevel exec mv $args
            }
            default {
                uplevel Tcl7.5_file $option $args
            }
        }
    }

} else {
    Oc_Log Log "OOMMF software does not support 
Tcl version 7.5 on non-Unix platforms.  
Please upgrade your Tcl installation." panic 
    exit
}
    
# Continue with bug patches for the next Tcl version
source [file join [file dirname [info script]] bug76.tcl]

